=============================
acdh-django-browsing
=============================

.. image:: https://badge.fury.io/py/acdh-django-browsing.svg
    :target: https://badge.fury.io/py/acdh-django-browsing

Django-App providing some useful things to create browsing views


Quickstart
----------

Install acdh-django-browsing:

    pip install acdh-django-browsing

Add it to your `INSTALLED_APPS`:

.. code-block:: python

    INSTALLED_APPS = (
        ...
        'browsing',
        ...
    )
